@@ -13,18 +13,18 @@ from time import sleep
 import requests
 
 from .version import __version__
-from .utils import backoff_retry
+from .utils import backoff_retry, print_with_time
 
 
 class Badminton():
     """珠海校区羽毛球场预订脚本
     """
 
-    def __init__(self, configpath, begin_time='00:01', max_times=10, token=''):
+    def __init__(self, configpath, begin_time='00:01', max_times=10, token='', auto_pay=True):
         self.session = requests.Session()
         self.headers = {
-            "Origin": "https://gym.sysu.edu.cn",
-            "Referer": "https://gym.sysu.edu.cn/order/show.html?id=161",
+            'Accept': '*/*',
+            'Accept-Encoding': 'gzip, deflate, br',
             "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 \
             (KHTML, like Gecko) Chrome/87.0.4280.66 Safari/537.36",
         }
@@ -32,6 +32,7 @@ class Badminton():
         self.capt, self.imbyte = None, None
         self.max_times = max_times
         self.token = token
+        self.auto_pay = auto_pay
 
         try:
             conf_par = configparser.ConfigParser()
@@ -40,17 +41,17 @@ class Badminton():
             self.first, self.stock_number = conf['first'], conf['stock_number']
             self.netid, self.password = conf['netid'], conf['password']
         except KeyError:
-            print('检查配置文件是否存在且正确填写')
+            print_with_time('检查配置文件是否存在且正确填写')
             sys.exit()
-        if (self.netid == '') or (self.password == ''):
-            print('填写 netid 和密码')
+        if not (self.netid and self.password):
+            print_with_time('填写 netid 和密码')
             sys.exit()
 
         try:
             self.stock_name = [int(i) for i in conf['stock_name'].split(',')]
             self.stock_time = [int(i) for i in conf['stock_time'].split(',')]
             self.stock_number = int(conf['stock_number'])
-            if conf['stock_date'] == '':
+            if not conf['stock_date']:
                 self.stock_date = date.today() + timedelta(days=2)
             else:
                 self.stock_date = datetime.strptime(
@@ -61,12 +62,13 @@ class Badminton():
                                                    self.begin_time) - timedelta(days=1)
             self.end_datetime = datetime.combine(self.stock_date, time(22, 0))
         except ValueError:
-            print('检查配置文件填写是否正确')
+            print_with_time('检查配置文件填写是否正确')
             sys.exit()
 
-        print(f'预订日期: {self.stock_date}')
-        print(f"预订场次: {conf['stock_name']}\n预订时间: {conf['stock_time']}")
-        print(f'每个时间段最大预订场地数: {self.stock_number}')
+        print_with_time(f'预订日期: {self.stock_date}')
+        print_with_time(f"预订场次: {conf['stock_name']}")
+        print_with_time(f"预订时间: {conf['stock_time']}")
+        print_with_time(f'每个时间段最大预订场地数: {self.stock_number}')
 
 
     def get_stocks(self):
@@ -81,9 +83,9 @@ class Badminton():
             try:
                 json_data = json.loads(r.text)
             except JSONDecodeError:
-                print(f'获取场地信息失败，第 {try_times} 次重试')
+                print_with_time(f'获取场地信息失败，第 {try_times} 次重试')
                 if r.status_code != 200:
-                    print(f'状态码: {r.status_code}，服务器可能崩溃了，等待一分钟后重试')
+                    print_with_time(f'状态码: {r.status_code}，服务器可能崩溃了，等待一分钟后重试')
                     sleep(60)
                     continue
                 sleep(3)
@@ -102,11 +104,11 @@ class Badminton():
                     dic['time_no'] = int(dic['time_full'][:2])
                     self.stocks.append(dic)
             if len(self.stocks) == 0:
-                print("凉了，没场地了，告辞")
+                print_with_time("凉了，没场地了，告辞")
                 sys.exit()
-            print(f'{self.stock_date} 共计 {len(self.stocks)} 个场地可以预订，开始按条件筛选')
+            print_with_time(f'{self.stock_date} 共计 {len(self.stocks)} 个场地可以预订，开始按条件筛选')
             return
-        print('获取场地信息失败，重试次数达到上限')
+        print_with_time('获取场地信息失败，重试次数达到上限')
         sys.exit()
 
 
@@ -118,7 +120,7 @@ class Badminton():
             if stock['sname'] in self.stock_name and stock['time_no'] in self.stock_time:
                 select.append(stock)
         if len(select) == 0:
-            print('没有满足条件的场地了')
+            print_with_time('没有满足条件的场地了')
             sys.exit()
         select.sort(key=lambda elem: (self.stock_time.index(elem['time_no']),
                                       self.stock_name.index(elem['sname'])))
@@ -135,9 +137,9 @@ class Badminton():
         if self.first == 'name':
             self.selects.sort(key=lambda elem: (self.stock_name.index(elem['sname']),
                                                 self.stock_time.index(elem['time_no'])))
-        print(f"共筛选出 {len(self.selects)} 个场地")
+        print_with_time(f"共筛选出 {len(self.selects)} 个场地")
         for stock in self.selects:
-            print(f"{stock['id']}  场地{stock['sname']}  {stock['time_full']}")
+            print_with_time(f"{stock['id']} 场地{stock['sname']} {stock['time_full']}")
 
 
     def _recognize(self):
@@ -148,32 +150,27 @@ class Badminton():
                 'User-Agent': 'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)'}
         files = {'imgfile': ('captcha.jpg', self.imbyte)}
         recg_times = 0
-        try:
-            while recg_times < self.max_times:
-                r = requests.post('https://cascaptcha.vercel.app/api', files=files, headers=headers)
-                arrstr = json.loads(r.text)
-                if arrstr["success"]:
-                    print(f'验证码识别成功: {arrstr["captcha"]}')
-                    self.capt = arrstr["captcha"]
-                    return True
-                recg_times += 1
-                print(f'识别失败，第 {recg_times} 次重试')
-                sleep(1)
-            raise Exception('识别失败，重试次数达到上限')
+        while recg_times < self.max_times:
+            r = requests.post('https://cascaptcha.vercel.app/api', files=files, headers=headers)
+            arrstr = json.loads(r.text)
+            if arrstr["success"]:
+                print_with_time(f'验证码识别成功: {arrstr["captcha"]}')
+                self.capt = arrstr["captcha"]
+                return True
+            recg_times += 1
+            print_with_time(f'识别失败，第 {recg_times} 次重试')
+            sleep(1)
 
-        except Exception as e:
-            with open('capt.jpg', 'wb') as f:
-                f.write(self.imbyte)
-            self.capt = input('验证码识别失败，请手动打开 capt.jpg 识别后输入\n')
+        with open('capt.jpg', 'wb') as f:
+            f.write(self.imbyte)
+        self.capt = input('验证码识别失败，请手动打开 capt.jpg 识别后输入\n')
 
 
     def login(self):
         """登录
         """
-        headers = {"User-Agent": self.headers['User-Agent']}
         login_url = "https://cas.sysu.edu.cn/cas/login"
         captcha_url = "https://cas.sysu.edu.cn/cas/captcha.jsp"
-        self_url = "https://gym.sysu.edu.cn/yyuser/personal.html"
         login_form = {"username": "",
                       "password": "",
                       "captcha": "",
@@ -181,36 +178,33 @@ class Badminton():
                       "geolocation": "",
                       }
         login_times = 0
+        print_with_time('开始登录')
 
         while login_times < self.max_times:
             login_times += 1
-            r = self.session.get(self_url, headers=headers)
-            if '欢迎' in r.text:
-                print('登录成功')
+            r = self.session.get(login_url, headers=self.headers)
+            if 'Log In Successful' in r.text:
+                print_with_time('登录成功')
                 return True
-
             self.imbyte = self.session.get(captcha_url).content
             self._recognize()
             login_form['captcha'] = self.capt
-
-            r = self.session.get(login_url)
             login_form['execution'] = findall('name="execution" value="(.*?)"', r.text)[0]
             login_form["username"] = self.netid
             login_form["password"] = self.password
 
-            r = self.session.post(login_url, headers=headers, data=login_form)
+            r = self.session.post(login_url, headers=self.headers, data=login_form)
             if 'success' in r.text:
-                print('登录成功')
-                r = self.session.get(self_url, headers=headers)
+                print_with_time('登录成功')
                 return True
             if 'credential' in r.text:
-                print('用户名或密码错误')
+                print_with_time('用户名或密码错误')
                 sys.exit()
 
-            print(f'验证码错误，第 {login_times} 次重试')
+            print_with_time(f'验证码错误，第 {login_times} 次重试')
             sleep(1)
 
-        print('登录重试次数太多，终止')
+        print_with_time('登录重试次数太多，终止')
         sys.exit()
 
 
@@ -220,25 +214,25 @@ class Badminton():
         now_time = datetime.now()
 
         if now_time > self.end_datetime:
-            print(f'预订日期已经过去，你可以穿越回 {self.end_datetime} 之前，再见')
+            print_with_time(f'预订日期已经过去，你可以穿越回 {self.end_datetime} 之前，再见')
             sys.exit()
 
         if now_time > self.begin_datetime:
             if now_time.hour < 22:
-                print(f'当前时间 {datetime.now()}，开始预订')
+                print_with_time(f'当前时间 {datetime.now()}，开始预订')
                 return
             self.begin_datetime += timedelta(days=1)
-            print('预订系统关闭，等到明天开始预订')
+            print_with_time('预订系统关闭，等到明天开始预订')
 
-        print(f'未到可预订时间，等到 {self.begin_datetime} 开始预订')
+        print_with_time(f'未到可预订时间，等到 {self.begin_datetime} 开始预订')
         if (self.begin_datetime - datetime.now()).days > 0:
-            print('!!!警告!!!')
-            print('等待时间超过一天，建议等到明天再来预订!!!')
-        print(f'{self.begin_datetime - datetime.now()} 后开始预订')
+            print_with_time('!!!警告!!!')
+            print_with_time('等待时间超过一天，建议等到明天再来预订!!!')
+        print_with_time(f'{self.begin_datetime - datetime.now()} 后开始预订')
         sleep((self.begin_datetime - datetime.now()).seconds - 120)
-        print('检查登录状态')
+        print_with_time('检查登录状态')
         if self.login():
-            print(f'{self.begin_datetime - datetime.now()} 后开始预订')
+            print_with_time(f'{self.begin_datetime - datetime.now()} 后开始预订')
             sleep((self.begin_datetime - datetime.now()).seconds - 3)
             return
 
@@ -248,12 +242,13 @@ class Badminton():
         """
         stock_index = 0
         book_times = 0
+        self.session.get('https://gym.sysu.edu.cn/yyuser/personal.html', headers=self.headers)
         while len(self.results) < 2 and book_times < 10:
             book_times += 1
             try:
                 stock = self.selects[stock_index]
             except IndexError:
-                print('可以预订的都试过了')
+                print_with_time('可以预订的都试过了')
                 break
             param = ('{"activityPrice":0,"activityStr":null,"address":null,"dates":null,'
                      '"extend":null,"flag":"0","isbookall":"0","isfreeman":"0","istimes":"1",'
@@ -268,37 +263,41 @@ class Badminton():
             try:
                 return_data = json.loads(r.text)
             except JSONDecodeError:
-                print(f'预订失败，第 {book_times} 次重试')
+                print_with_time(f'预订失败，第 {book_times} 次重试')
                 sleep(10)
                 continue
 
             if return_data['result'] == '2':
-                print(
-                    f'场地{stock["sname"]} {stock["s_date"]} {stock["time_full"]} 预订成功，待支付')
+                print_with_time(f'预订成功：场地 {stock["sname"]} {stock["time_full"]} '
+                                f'订单号 {return_data["object"]["orderid"]}，待支付')
                 stock_index += 1
                 self.results.append([return_data['object']['orderid'],
                                     stock["sname"], stock["s_date"], stock["time_no"]])
 
             elif return_data['message'] == 'USERNOTLOGINYET':
-                print('JSESSIONID 过期了，重新登录')
+                print_with_time('JSESSIONID 过期了，重新登录')
+                sleep(1)
                 self.login()
                 continue
 
             elif '已被预订' in return_data['message']:
                 stock_index += 1
-                print('场次已被预订，尝试下一个')
+                print_with_time('场次已被预订，尝试下一个')
                 continue
 
             else:
-                print(f'预订失败：{return_data["message"]}，第 {book_times} 次重试')
+                print_with_time(f'预订失败：{return_data["message"]}，第 {book_times} 次重试')
                 sleep(10)
                 continue
 
         if len(self.results) == 0:
-            print('预订失败，重试次数过多，退出')
+            print_with_time('预订失败，重试次数过多，退出')
             sys.exit()
-        print(f'预订成功 {len(self.results)} 个场地，1 分钟后自动支付订单')
-        sleep(60)
+        if not self.auto_pay:
+            print_with_time(f'预订成功 {len(self.results)} 个场地，请自行支付')
+            sys.exit()
+        print_with_time(f'预订成功 {len(self.results)} 个场地，10 秒后自动支付订单')
+        sleep(10)
 
 
     def pay(self):
@@ -308,7 +307,7 @@ class Badminton():
         while pay_times < self.max_times and len(self.results) != 0:
             pay_times += 1
             result = self.results[0]
-            print('支付订单  ' + str(result[0]))
+            print_with_time('支付订单 ' + str(result[0]))
             data1 = {"orderid": result[0], "payid": 2}
             headers = self.headers
             headers['Referer'] = f'https://gym.sysu.edu.cn/pay/show.html?id={result[0]}'
@@ -322,19 +321,20 @@ class Badminton():
             try:
                 return_data = json.loads(r.text)
             except JSONDecodeError:
-                print(f'支付失败，第 {pay_times} 次重试')
+                print_with_time(f'支付失败，第 {pay_times} 次重试')
                 sleep(5)
                 self.login()
                 continue
             if return_data["result"] == "1":
-                print(f'{str(result[0])} 支付成功')
+                print_with_time(f'{str(result[0])} 支付成功')
                 self.results.remove(result)
             else:
-                print(f'支付结果: {return_data["message"]}，重试')
+                print_with_time(f'支付结果: {return_data["message"]}，重试')
                 sleep(5)
 
         if len(self.results) != 0:
-            print('可能有未成功支付的订单，请手动支付')
+            print_with_time('可能有未成功支付的订单，请手动支付')
+
 
     @backoff_retry
     def run(self):
@@ -352,12 +352,17 @@ def main():
     parser.add_argument('config', type=str, help='配置文件路径')
     parser.add_argument('-b', '--begin', metavar='BEGIN TIME', type=str,
                         help='预订开始时间，如 00:05，默认 00:01', default='00:01')
-    parser.add_argument('-m', '--maxtimes', type=int,
-                        help='最大重试次数', default=10)
-    parser.add_argument('-t', '--token', type=str,
-                        help='cascaptcha api token', default='j6NKyDMPRxjHNHukp7WbBLxycL')
-    parser.add_argument('-v', '--version', action='version',
-                        version=f'%(prog)s {__version__}')
+    parser.add_argument('-p', '--pay', metavar='AUTO PAY', type=str,
+                        help='是否自动支付，默认为开启', default='True')
+    parser.add_argument('-m', '--maxtimes', type=int, help='最大重试次数', default=10)
+    parser.add_argument('-t', '--token', type=str, help='cascaptcha api token',
+                        default='j6NKyDMPRxjHNHukp7WbBLxycL')
+    parser.add_argument('-v', action='version', version=f'%(prog)s {__version__}')
+
     par = parser.parse_args()
-    badminton = Badminton(par.config, par.begin, par.maxtimes, par.token)
+    if par.pay in ['true', 'True', 'TRUE', '1']:
+        par.pay = True
+    else:
+        par.pay = False
+    badminton = Badminton(par.config, par.begin, par.maxtimes, par.token, par.pay)
     badminton.run()
